read_to_string_capped

Function read_to_string_capped 

pub fn read_to_string_capped(path: &Path) -> Result<String>
Reads a file into a String, refusing files larger than MAX_FILE_SIZE.

Convenience wrapper over read_to_string_capped_with_limit for the many scan readers that use the default cap.