pub struct SubagentScanner { /* private fields */ }Expand description
Scanner for Claude Code subagent definitions in .claude/agents/
Implementations
Sourceimpl SubagentScanner
impl SubagentScanner
Sourcepub fn with_skip_comments(self, skip: bool) -> Self
pub fn with_skip_comments(self, skip: bool) -> Self
Enables or disables comment skipping during scanning.
Sourcepub fn with_dynamic_rules(self, rules: Vec<DynamicRule>) -> Self
pub fn with_dynamic_rules(self, rules: Vec<DynamicRule>) -> Self
Adds dynamic rules loaded from custom YAML files.
Sourcepub fn with_strict_secrets(self, strict: bool) -> Self
pub fn with_strict_secrets(self, strict: bool) -> Self
Enables or disables strict secrets mode. When enabled, dummy key heuristics are disabled for test files.
Sourcepub fn with_inline_suppression(self, allow: bool) -> Self
pub fn with_inline_suppression(self, allow: bool) -> Self
Enables honoring of in-band suppression directives read from scanned content. Off by default (secure for untrusted scans).
Sourcepub fn with_recursive(self, recursive: bool) -> Self
pub fn with_recursive(self, recursive: bool) -> Self
Enables or disables recursive scanning. When disabled, only scans the immediate directory (max_depth = 1).
Sourcepub fn with_max_file_size(self, max_file_size: u64) -> Self
pub fn with_max_file_size(self, max_file_size: u64) -> Self
Overrides the maximum size (in bytes) of a file that will be read into memory. Files above the cap are refused before allocation.
Sourcepub fn with_progress_callback(self, callback: ProgressCallback) -> Self
pub fn with_progress_callback(self, callback: ProgressCallback) -> Self
Sets a progress callback that will be called for each scanned file.